@@ -33,12 +33,13 @@ import relex.chunk.PatternChunker;
 import relex.chunk.PhraseChunker;
 import relex.chunk.RelationChunker;
 import relex.concurrent.RelexContext;
-import relex.corpus.EntityMaintainerFactory;
 // import relex.corpus.QuotesParensSentenceDetector;
 import relex.corpus.DocSplitter;
 import relex.corpus.DocSplitterFactory;
 import relex.entity.EntityInfo;
 import relex.entity.EntityMaintainer;
+import relex.entity.EntityTagger;
+import relex.entity.EntityTaggerFactory;
 import relex.feature.FeatureNode;
 import relex.feature.LinkView;
 import relex.frame.Frame;
@@ -101,15 +102,22 @@ public class RelationExtractor
 	/** Document - holder of sentences */
 	Document doco;
 
-	/* Stanford parser compatibility mode */
+	/** Stanford parser compatibility mode */
 	public boolean do_stanford;
 
-	/* Penn tagset compatibility mode */
+	/** Penn tagset compatibility mode */
 	public boolean do_penn_tagging;
 
-	/* Expand preposition markup to two dependencies. */
+	/** Expand preposition markup to two dependencies. */
 	public boolean do_expand_preps;
 
+	/** Perform entity substitution before parsing */
+	public boolean do_pre_entity_tagging;
+
+	/** Perform entity tagging after parse */
+	public boolean do_post_entity_tagging;
+	public EntityTagger tagger;
+
 	/** Statistics */
 	private ParseStats stats;
 
@@ -150,6 +158,9 @@ public class RelationExtractor
 		do_stanford = false;
 		do_penn_tagging = false;
 		do_expand_preps = false;
+		do_pre_entity_tagging = false;
+		do_post_entity_tagging = false;
+		tagger = null;
 
 		stats = new ParseStats();
 		sumtime = new TreeMap<String,Long>();
@@ -212,8 +223,7 @@ public class RelationExtractor
 		starttime = System.currentTimeMillis();
 		if (entityMaintainer == null)
 		{
-			entityMaintainer = new EntityMaintainer(sentence,
-		                               new ArrayList<EntityInfo>());
+			entityMaintainer = new EntityMaintainer();
 		}
 
 		Sentence sntc = null;
@@ -230,9 +240,17 @@ public class RelationExtractor
 					parse.getLeft().set("expand-preps", new FeatureNode("T"));
 				}
 
+				if (do_post_entity_tagging && (tagger != null))
+				{
+					// Markup feature node graph with entity info,
+					// so that the relex algs (next step) can see them.
+					tagger.tagEntities(sentence);
+					tagger.tagParse(parse);
+				}
+
 				// Markup feature node graph with entity info,
 				// so that the relex algs (next step) can see them.
-				entityMaintainer.prepareSentence(parse.getLeft());
+				entityMaintainer.tagConvertedSentence(parse);
 
 				// The actual relation extraction is done here.
 				sentenceAlgorithmApplier.applyAlgs(parse, context);
@@ -252,6 +270,7 @@ public class RelationExtractor
 					PhraseTree pt = new PhraseTree(parse.getLeft());
 					parse.setPhraseString(pt.toString());
 				}
+
 			}
 
 			// Assign a simple parse-ranking score, based on LinkGrammar data.
@@ -266,7 +285,7 @@ public class RelationExtractor
 		}
 		catch(Exception e)
 		{
-			System.err.println("Failed to process sentence: " + sentence);
+			System.err.println("Error: Failed to process sentence: " + sentence);
 			e.printStackTrace();
 		}
 		if (verbosity > 0) reportTime("RelEx processing: ");
@@ -281,7 +300,9 @@ public class RelationExtractor
 	private Sentence
 	parseSentence(String sentence, EntityMaintainer entityMaintainer)
 	{
-		if (entityMaintainer != null) {
+		if (entityMaintainer != null)
+		{
+			entityMaintainer.convertSentence(sentence,null);
 			sentence = entityMaintainer.getConvertedSentence();
 		}
 		if (sentence == null) return null;
@@ -369,7 +390,8 @@ public class RelationExtractor
 			" [-c (show plain output)]" +
 			" [--expand-preps (show expanded prepositions)]" +
 			" [-f (show frame output)]" +
-			" [-g (use GATE entity detector)]" +
+			" [-g (pre-process with GATE entity detector)]" +
+			" [--g-post (post-process with GATE entity detector)]" +
 			" [-h (show this help)]" +
 			" [-l (show parse links)]" +
 			" [-m (show parse metadata)]" +
@@ -394,6 +416,7 @@ public class RelationExtractor
 		flags.add("--expand-preps");
 		flags.add("-f");
 		flags.add("-g");
+		flags.add("--g-post");
 		flags.add("-h");
 		flags.add("-l");
 		flags.add("-m");
@@ -487,14 +510,18 @@ public class RelationExtractor
 			re.do_expand_preps = true;
 		}
 
-		EntityMaintainerFactory gem = null;
-		if (commandMap.get("-g") != null)
+		EntityTagger gent = null;
+		if ((commandMap.get("-g") != null) ||
+		    (commandMap.get("--g-post") != null))
 		{
 			re.starttime = System.currentTimeMillis();
-			gem = EntityMaintainerFactory.get();
-			gem.makeEntityMaintainer(""); // force initialization to measure initialization time
-			re.reportTime("Entity Detection Initialization: ");
+			gent = EntityTaggerFactory.get();
+			gent.tagEntities(""); // force initialization to measure initialization time
+			re.tagger = gent;
+			re.reportTime("Entity Detector Initialization: ");
 		}
+		if (commandMap.get("-g") != null) re.do_pre_entity_tagging = true;
+		if (commandMap.get("--g-post") != null) re.do_post_entity_tagging = true;
 
 		// If sentence is not passed at command line, read from standard input:
 		BufferedReader stdin = new BufferedReader(new InputStreamReader(System.in));
@@ -565,10 +592,13 @@ public class RelationExtractor
 			{
 				System.out.println("; SENTENCE: ["+sentence+"]");
 				EntityMaintainer em = null;
-				if (gem != null)
+				if (re.do_pre_entity_tagging)
 				{
 					re.starttime = System.currentTimeMillis();
-					em = gem.makeEntityMaintainer(sentence);
+					em = new EntityMaintainer();
+					gent.reset();
+					em.set(gent);
+					// gent.makeEntityTagger(sentence));
 					re.reportTime("Gate processing: ");
 				}
 				Sentence sntc = re.processSentence(sentence,em);
