@@ -24,6 +24,7 @@ import relex.Sentence;
 import relex.algs.SentenceAlgorithmApplier;
 import relex.entity.EntityMaintainer;
 import relex.tree.PhraseMarkup;
+import relex.tree.PhraseTree;
 
 /**
  * Processes a sentence using the given LinkParserClient. When processing is
@@ -64,6 +65,7 @@ public class RelexTask implements Callable<RelexTaskResult>
 	public RelexTaskResult call() {
 		try {
 			if (DEBUG > 0) System.err.println("[" + index + "] Start processing "+ sentence);
+			entityMaintainer.convertSentence(sentence,null);
 			String convertedSentence = entityMaintainer.getConvertedSentence().replace('\n', ' ').replace('\r', ' ');
 			if (DEBUG > 0) System.err.println("[" + index + "] End entity detection");
 			Sentence sntc = null;
@@ -81,7 +83,7 @@ public class RelexTask implements Callable<RelexTaskResult>
 				try {
 					// Markup feature node graph with entity info,
 					// so that the relex algs (next step) can see them.
-					entityMaintainer.prepareSentence(parse.getLeft());
+					entityMaintainer.tagConvertedSentence(parse);
 
 					// The actual relation extraction is done here.
 					sentenceAlgorithmApplier.applyAlgs(parse, context);
@@ -92,7 +94,12 @@ public class RelexTask implements Callable<RelexTaskResult>
 
 					// Also do a Penn tree-bank style phrase structure markup.
 					if (phraseMarkup != null)
+					{
 						phraseMarkup.markup(parse);
+						// Repair the entity-mangled tree-bank string.
+						PhraseTree pt = new PhraseTree(parse.getLeft());
+						parse.setPhraseString(pt.toString());
+					}
 				} catch (Exception e) {
 					e.printStackTrace();
 				}
