@@ -228,16 +228,18 @@ public class CompactView
 				str += getfeat(ref, "QUERY-TYPE");
 				str += getfeat(ref, "inflection-TAG");
 
-				str += getflag(ref, "DATE-FLAG");
-				str += getflag(ref, "DEFINITE-FLAG");
-				str += getflag(ref, "EMOTICON-FLAG");
-				str += getflag(ref, "ENTITY-FLAG");
-				str += getflag(ref, "IDIOM-FLAG");
-				str += getflag(ref, "LOCATION-FLAG");
-				str += getflag(ref, "MONEY-FLAG");
-				str += getflag(ref, "ORGANIZATION-FLAG");
-				str += getflag(ref, "PERSON-FLAG");
-				str += getflag(ref, "POLYWORD-FLAG");
+				str += getflag(ref, "date-FLAG");
+				str += getflag(ref, "definite-FLAG");
+				str += getflag(ref, "emoticon-FLAG");
+				str += getflag(ref, "entity-FLAG");
+				str += getflag(ref, "idiom-FLAG");
+				str += getflag(ref, "location-FLAG");
+				str += getflag(ref, "money-FLAG");
+				str += getflag(ref, "organization-FLAG");
+				str += getflag(ref, "person-FLAG");
+				str += getflag(ref, "polyword-FLAG");
+				str += getflag(ref, "pronoun-FLAG");
+				str += getflag(ref, "time-FLAG");
 			}
 
 			notfirst = false;
