@@ -3,7 +3,7 @@
  * by Rui P. Costa (adapted from SimpleView and RelationView)
  *
  * Created in 2008 by "Rui Costa" <racosta@student.dei.uc.pt>,
- *                    "Rui Costa" * <racosta@student.dei.uc.pt>
+ *                     Rui P. Costa <b4h0pe@gmail.com>
  */
 package relex.output;
 
@@ -83,7 +83,7 @@ public class OWLView
 	*	_subj(throw, John)
 	*	_obj(throw, ball)
 	*	tense(throw, past)
-	*	DEFINITE-FLAG(ball, T)
+	*	definite-FLAG(ball, T)
 	*	noun_number(ball, singular)
 	*/
 	public void printRelations(ParsedSentence parse, String sentence, int sentence_id, String ontologyname)
